#!/usr/bin/env python3
#coding:utf-8
# Author:  Wolfram Eifler --<notiznetz@weifler.in-berlin.de>
# Purpose: Editor for text-content of a note
# Created: 01/26/2017
# Copyright 2017, Wolfram Eifler
# Usage-Permission: GNU General Public License version 3 as published by the
# Free Software Foundation. The full text of the license is availabe
# in this distribution in the file licenses/gpl-v3.txt or
# via internet at http://www.gnu.org/licenses/gpl-3.0.html
"""
Editor for text-content of a note
"""

import unittest
import sys, os
from PyQt5 import Qt, QtGui, QtWidgets, QtCore
import notiznetz
from notiznetz import Ui_EditText
from notiznetz.util import *

class EditView(QtWidgets.QDialog, Ui_EditText):
    def __init__(self, note, parent=None):
        super(EditView, self).__init__(parent)
        self.setupUi(self)
        self.p = parent
        self.note = note
        self.editor.setText(note.getText())
        self.setWindowTitle(note.headlinetext.toPlainText())
        self.text_changed = False
        #assert(isinstance(self.editor, QtWidgets.QTextEdit))
        self.editor.textChanged.connect(self.onTextChange)
        # This signal is emitted whenever the document's content changes;
        # for example, when text is inserted or deleted, or when formatting is applied.

    def _deliverText(self):
        # deliver text to parent here
        oldtxt = self.note.getText()
        newtxt = self.editor.toPlainText()
        if oldtxt != newtxt:
            self.p.signalDataChange()
        self.note.setText(newtxt)

    def onTextChange(self):
        """for first change append ' *' to self.windowTitle"""
        if not self.text_changed:
            self.text_changed = True
            self.setWindowTitle(self.windowTitle() + " *")

    def closeWindow(self):
        self._deliverText()
        self.close()

    def closeEvent(self, e):
        self.closeWindow()
        e.accept()

    def keyPressEvent(self, e):
        k = e.key()
        if (e.modifiers() == QtCore.Qt.ControlModifier):
            if (k == QtCore.Qt.Key_W):
                self.closeWindow()
            if (k == QtCore.Qt.Key_S):
                self._deliverText()
                self.p.save()
                wt = self.windowTitle()
                if wt.endswith(' *'):
                    self.setWindowTitle(wt[:-2])
        elif (k == QtCore.Qt.Key_Escape):
            self.closeWindow()

if __name__ == '__main__':
    unittest.main()
